@@ -172,7 +172,7 @@ class Config:
         self.frontend = 'pager'
         self.email_address = None
         self.verbose = False
-        self.quiet = False
+        self.quiet = 0
         self.show_all = False
         self.confirm = False
         self.headers = False
@@ -293,7 +293,7 @@ def read_apt_pipeline(config):
         (option, value) = aptconfig.rstrip().split('=', 1)
         
         if option == 'quiet':
-            config.quiet = value
+            config.quiet = int(value)
 
     filenames = {}
     order = []
@@ -396,6 +396,9 @@ class ttyconfirm:
 
 class simpleprogress:
     def update_progress(self):
+        if self.config.quiet > 1:
+            return
+        
         if not hasattr(self,'message_printed'):
             self.message_printed = 1
             sys.stderr.write(_("Reading changelogs") + "...\n")
